==> milvus_haystack-0.0.3.tar.gz: milvus_haystack-0.0.3/tests/test_embedding_retriever.py <==
import pytest
from haystack import Document
from src.milvus_haystack import MilvusDocumentStore
from src.milvus_haystack.milvus_embedding_retriever import MilvusEmbeddingRetriever


class TestMilvusEmbeddingTests:
    from milvus import MilvusServer
    milvus_server = MilvusServer()
    milvus_server.set_base_dir("test_milvus_base")
    milvus_server.listen_port = 19530
    try:
        milvus_server.stop()
    except:
        pass
    try:
        milvus_server.cleanup()
    except:
        pass
    try:
        milvus_server.start()
    except:
        pass

    @pytest.fixture
    def document_store(self) -> MilvusDocumentStore:
        return MilvusDocumentStore(
            connection_args={
                "host": "localhost",
                "port": "19530",
                "user": "",
                "password": "",
                "secure": False,
            },
            drop_old=True,
        )

    def test_run(self, document_store: MilvusDocumentStore):
        documents = []
        doc = Document(
            content="A Foo Document",
            meta={
                "name": "name_0",
                "page": "100",
                "chapter": "intro",
                "number": 2,
                "date": "1969-07-21T20:17:40",
            },
            embedding=[-10.0] * 128,
        )
        documents.append(doc)
        document_store.write_documents(documents)
        retriever = MilvusEmbeddingRetriever(document_store, )
        query_embedding = [-10.0] * 128
        res = retriever.run(query_embedding)
        assert res["documents"] == doc

==> milvus_haystack-0.0.4.tar.gz: milvus_haystack-0.0.4/tests/test_embedding_retriever.py <==
import logging

import pytest
from haystack import Document

from src.milvus_haystack import MilvusDocumentStore
from src.milvus_haystack.milvus_embedding_retriever import MilvusEmbeddingRetriever

logger = logging.getLogger(__name__)


class TestMilvusEmbeddingTests:
    from milvus import MilvusServer

    milvus_server = MilvusServer()
    milvus_server.set_base_dir("test_milvus_base")
    milvus_server.listen_port = 19530
    try:
        milvus_server.stop()
    except Exception as err:
        logger.debug("Can not stop Milvus server. %s", err)
    try:
        milvus_server.cleanup()
    except Exception as err:
        logger.debug("Can not cleanup Milvus. %s", err)
    try:
        milvus_server.start()
    except Exception as err:
        logger.debug("Can not start Milvus server. %s", err)

    @pytest.fixture
    def document_store(self) -> MilvusDocumentStore:
        return MilvusDocumentStore(
            connection_args={
                "host": "localhost",
                "port": "19530",
                "user": "",
                "password": "",
                "secure": False,
            },
            drop_old=True,
        )

    def test_run(self, document_store: MilvusDocumentStore):
        documents = []
        doc = Document(
            content="A Foo Document",
            meta={
                "name": "name_0",
                "page": "100",
                "chapter": "intro",
                "number": 2,
                "date": "1969-07-21T20:17:40",
            },
            embedding=[-10.0] * 128,
        )
        documents.append(doc)
        document_store.write_documents(documents)
        retriever = MilvusEmbeddingRetriever(
            document_store,
        )
        query_embedding = [-10.0] * 128
        res = retriever.run(query_embedding)
        assert res["documents"] == documents
